<?xml version="1.0" encoding="UTF-8"?>
<rss xmlns:content="http://purl.org/rss/1.0/modules/content/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:taxo="http://purl.org/rss/1.0/modules/taxonomy/" version="2.0">
  <channel>
    <title>topic OpenCL Graphics Driver 30.0.101.1069 Issue in Graphics</title>
    <link>https://community.intel.com/t5/Graphics/OpenCL-Graphics-Driver-30-0-101-1069-Issue/m-p/1413601#M109657</link>
    <description>&lt;DIV class="lia-quilt-column lia-quilt-column-24 lia-quilt-column-single lia-quilt-column-message-body-content"&gt;
&lt;DIV class="lia-quilt-column-alley lia-quilt-column-alley-single"&gt;
&lt;P class="sub_section_element_selectors" style="word-wrap: break-word; font-size: 12px;"&gt;&lt;FONT size="2"&gt;&lt;SPAN class="sub_section_element_selectors"&gt;Hi all,&lt;/SPAN&gt;&lt;/FONT&gt;&lt;/P&gt;
&lt;P class="sub_section_element_selectors" style="word-wrap: break-word; font-size: 12px;"&gt;&lt;FONT size="2"&gt;I have just upgraded to the latest Intel Graphics Driver and I can no longer build opencl programs from spirv.&amp;nbsp; It seems image3d write is broken/missing as I get the following error for a simple opencl kernel:&lt;/FONT&gt;&lt;/P&gt;
&lt;PRE&gt;&lt;FONT size="2"&gt;failed to build opencl program:&lt;/FONT&gt;&lt;BR /&gt;&lt;BR /&gt;&lt;FONT size="2"&gt;error: undefined reference to `__builtin_spirv_OpImageWrite_img3d_wo_v3i32_v4f32'&lt;/FONT&gt;&lt;BR /&gt;&lt;FONT size="2"&gt;in function: '__builtin_spirv_OpImageWrite_img3d_wo_v3i32_v4f32' called by kernel: 'driver_test2'&lt;/FONT&gt;&lt;BR /&gt;&lt;BR /&gt;&lt;FONT size="2"&gt;error: backend compiler failed build.&lt;/FONT&gt;&lt;/PRE&gt;
&lt;P class="sub_section_element_selectors" style="word-wrap: break-word; font-size: 12px;"&gt;&lt;FONT size="2"&gt;&amp;nbsp;here is a simple kernel that triggers this:&lt;/FONT&gt;&lt;/P&gt;
&lt;LI-CODE lang="markup"&gt;#include &amp;lt;opencl_memory&amp;gt;
#include &amp;lt;opencl_work_item&amp;gt;
#include &amp;lt;opencl_image&amp;gt;
#include &amp;lt;opencl_integer&amp;gt;

using namespace cl;

kernel void driver_test(
    image3d&amp;lt;float4, image_access::write&amp;gt; dst_vol
) {
    const int3 dst_coords(get_global_id(0), get_global_id(1), get_global_id(2));

    float4 source_sample(0.0f,0.0f,0.0f,0.0f);
    dst_vol.write(dst_coords, source_sample);  
}&lt;/LI-CODE&gt;
&lt;P class="sub_section_element_selectors" style="word-wrap: break-word; font-size: 12px;"&gt;&lt;FONT size="2"&gt;&lt;SPAN class="sub_section_element_selectors"&gt;and the cpp part:&lt;/SPAN&gt;&lt;/FONT&gt;&lt;/P&gt;
&lt;LI-CODE lang="markup"&gt;#include "CL/cl.h"
#include &amp;lt;iostream&amp;gt;
#include &amp;lt;fstream&amp;gt;

#define MAX_PLATFORM_SIZE 256
#define MAX_DEVICE_SIZE 256

std::vector&amp;lt;unsigned char&amp;gt; load_file(const std::string&amp;amp; file)
{
    std::fstream input(file, std::ios::in | std::ios::binary | std::ios::ate);
    auto size = input.tellg();
    input.seekg(0, std::ios::beg);
    std::vector&amp;lt;unsigned char&amp;gt; binary(size);
    input.read((char*)binary.data(),size);
    input.close();

    return binary;
}

void driver_test()
{  
    std::vector&amp;lt;unsigned char&amp;gt; data = load_file("driver_test.spir");

    cl_device_id device_id[256];
    cl_platform_id platform_id[256];
    cl_uint ret_num_devices;
    cl_uint ret_num_platforms;
    char buf[4096];

    cl_int ret = clGetPlatformIDs(0, 0, &amp;amp;ret_num_platforms);
    ret = clGetPlatformIDs(ret_num_platforms, platform_id, &amp;amp;ret_num_platforms);
    if (ret != CL_SUCCESS) {
        std::cout &amp;lt;&amp;lt; "something went wrong in clGetPlatformIDs" &amp;lt;&amp;lt; std::endl;
        return;
    }

    for (unsigned int i=0; i&amp;lt;ret_num_platforms; i++) 
    {
        ret = clGetPlatformInfo(platform_id[i], CL_PLATFORM_NAME, sizeof(buf), buf, NULL);
        if (ret != CL_SUCCESS) {
            std::cout &amp;lt;&amp;lt; "something went wrong in clGetPlatformInfo" &amp;lt;&amp;lt; std::endl;
            return;
        }
        std::cout &amp;lt;&amp;lt; "Platform[" &amp;lt;&amp;lt; i &amp;lt;&amp;lt; "]: " &amp;lt;&amp;lt; buf &amp;lt;&amp;lt; std::endl;

        ret = clGetDeviceIDs(platform_id[i], CL_DEVICE_TYPE_ALL, MAX_DEVICE_SIZE, device_id, &amp;amp;ret_num_devices);
        if (ret != CL_SUCCESS) {
            std::cout &amp;lt;&amp;lt; "something went wrong in clGetDeviceIDs" &amp;lt;&amp;lt; std::endl;
            return;
        }

        for (unsigned int j=0; j&amp;lt;ret_num_devices; j++) {
            ret = clGetDeviceInfo(device_id[j], CL_DEVICE_NAME, sizeof(buf), buf, NULL);
            if (ret != CL_SUCCESS) {
                std::cout &amp;lt;&amp;lt; "something went wrong in clGetDeviceInfo" &amp;lt;&amp;lt; std::endl;
                return;
            }
            std::cout &amp;lt;&amp;lt; "Device Name: " &amp;lt;&amp;lt; buf &amp;lt;&amp;lt; std::endl;

            ret = clGetDeviceInfo(device_id[j], CL_DEVICE_VENDOR, sizeof(buf), buf, NULL);
            if (ret != CL_SUCCESS) {
                std::cout &amp;lt;&amp;lt; "something went wrong in clGetDeviceInfo" &amp;lt;&amp;lt; std::endl;
                return;
            }
            std::cout &amp;lt;&amp;lt; "Device Vendor: " &amp;lt;&amp;lt; buf &amp;lt;&amp;lt; std::endl;
        }
        std::cout &amp;lt;&amp;lt; std::endl;
    }
 
    cl_context context = clCreateContext( NULL, 1, &amp;amp;device_id[0], NULL, NULL, &amp;amp;ret);
 
    cl_int err = 0;
    cl_program program = clCreateProgramWithIL((cl_context)context, data.data(), data.size(), &amp;amp;err); 
    if(err != CL_SUCCESS){
        std::cout &amp;lt;&amp;lt; "failed to create opencl program with IL " &amp;lt;&amp;lt; std::endl;
        return;
    }

    // sometimes crashes here
    err = clBuildProgram(program, 1, &amp;amp;device_id[0], NULL, NULL, NULL);

    cl_int build_status;
    err = clGetProgramBuildInfo(program, device_id[0], CL_PROGRAM_BUILD_STATUS, sizeof(cl_build_status), &amp;amp;build_status, NULL);

    if(build_status != CL_SUCCESS){
        size_t ret_val_size;
        err = clGetProgramBuildInfo(program, device_id[0], CL_PROGRAM_BUILD_LOG, 0, NULL, &amp;amp;ret_val_size);
                 
        std::vector&amp;lt;char&amp;gt; build_log(ret_val_size+1,0);
        err = clGetProgramBuildInfo(program, device_id[0], CL_PROGRAM_BUILD_LOG, ret_val_size, build_log.data(), NULL);

        build_log[ret_val_size] = '\0';
        std::cout &amp;lt;&amp;lt; "failed to build opencl program: \n" &amp;lt;&amp;lt; build_log.data() &amp;lt;&amp;lt; std::endl;
    }
}
&lt;/LI-CODE&gt;
&lt;P class="sub_section_element_selectors" style="word-wrap: break-word; font-size: 12px;"&gt;&lt;FONT size="2"&gt;I've been rolling back the driver versions and the earliest driver where this happens is: &lt;STRONG&gt;30.0.101.1069&lt;/STRONG&gt;&lt;/FONT&gt;&lt;/P&gt;
&lt;P class="sub_section_element_selectors" style="word-wrap: break-word; font-size: 12px;"&gt;&lt;FONT size="2"&gt;Earlier driver version work fine&lt;/FONT&gt;&lt;/P&gt;
&lt;P class="sub_section_element_selectors" style="word-wrap: break-word; font-size: 12px;"&gt;&lt;FONT size="2"&gt;Sometimes it crashes at clBuildProgram too. &lt;/FONT&gt;&lt;/P&gt;
&lt;P class="sub_section_element_selectors" style="word-wrap: break-word; font-size: 12px;"&gt;&lt;FONT size="2"&gt;I have attached the .cl, cpp and .spir files.&amp;nbsp; We use:&lt;BR /&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp; &lt;A href="https://github.com/KhronosGroup/SPIRV-LLVM" target="_self"&gt;SPIRV-LLVM&lt;/A&gt;&lt;BR /&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp; &lt;A href="https://github.com/KhronosGroup/SPIR" target="_self"&gt;SPIR &lt;/A&gt;&lt;BR /&gt;&lt;/FONT&gt;&lt;FONT size="2"&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp; &lt;A href="https://github.com/KhronosGroup/libclcxx" target="_self"&gt;libclcxx&lt;/A&gt;&lt;/FONT&gt;&lt;/P&gt;
&lt;P class="sub_section_element_selectors" style="word-wrap: break-word; font-size: 12px;"&gt;&lt;FONT size="2"&gt;to generate the spirv file.&amp;nbsp; I've attached the generated spirv for easier testing.&lt;/FONT&gt;&lt;/P&gt;
&lt;P class="sub_section_element_selectors" style="word-wrap: break-word; font-size: 12px;"&gt;&lt;FONT size="2"&gt;Any help would be appreciated.&lt;/FONT&gt;&lt;/P&gt;
&lt;P class="sub_section_element_selectors" style="word-wrap: break-word; font-size: 12px;"&gt;&lt;FONT size="2"&gt;Regards&lt;/FONT&gt;&lt;BR /&gt;&lt;FONT size="2"&gt;Scott&lt;/FONT&gt;&lt;/P&gt;
&lt;P class="sub_section_element_selectors" style="word-wrap: break-word; font-size: 12px;"&gt;&amp;nbsp;&lt;/P&gt;
&lt;P class="sub_section_element_selectors" style="word-wrap: break-word; font-size: 12px;"&gt;&lt;FONT size="2"&gt;&lt;SPAN class="sub_section_element_selectors"&gt;System Setup Information:&lt;/SPAN&gt;&lt;/FONT&gt;&lt;BR /&gt;&lt;FONT size="2"&gt;&lt;SPAN class="sub_section_element_selectors"&gt; -----------------------------------------&lt;/SPAN&gt;&lt;/FONT&gt;&lt;/P&gt;
&lt;P class="sub_section_element_selectors" style="word-wrap: break-word; font-size: 12px;"&gt;&lt;FONT size="2"&gt;&lt;SPAN class="sub_section_element_selectors"&gt;System Used: Inspiron 3670&lt;/SPAN&gt;&lt;/FONT&gt;&lt;BR /&gt;&lt;FONT size="2"&gt;&lt;SPAN class="sub_section_element_selectors"&gt; CPU SKU: Intel(R) Core(TM) i3-8100 CPU @ 3.60GHz 3.60 GHz&lt;/SPAN&gt;&lt;/FONT&gt;&lt;BR /&gt;&lt;FONT size="2"&gt;&lt;SPAN class="sub_section_element_selectors"&gt; GPU SKU: Intel(R) UHD Graphics 630&lt;/SPAN&gt;&lt;/FONT&gt;&lt;BR /&gt;&lt;FONT size="2"&gt;&lt;SPAN class="sub_section_element_selectors"&gt; System BIOS Version: Dell Inc. 1.3.4, 24/05/2018&lt;/SPAN&gt;&lt;/FONT&gt;&lt;BR /&gt;&lt;FONT size="2"&gt;&lt;SPAN class="sub_section_element_selectors"&gt; Graphics Driver Version: 30.0.101.1069&lt;/SPAN&gt;&lt;/FONT&gt;&lt;BR /&gt;&lt;FONT size="2"&gt;&lt;SPAN class="sub_section_element_selectors"&gt; Operating System:&amp;nbsp; Windows 10 Pro&lt;/SPAN&gt;&lt;/FONT&gt;&lt;BR /&gt;&lt;FONT size="2"&gt;&lt;SPAN class="sub_section_element_selectors"&gt; OS Version: 10.0.19042 Build 19042&lt;/SPAN&gt;&lt;/FONT&gt;&lt;BR /&gt;&lt;FONT size="2"&gt;&lt;SPAN class="sub_section_element_selectors"&gt; API: OpenCL&lt;/SPAN&gt;&lt;/FONT&gt;&lt;BR /&gt;&lt;FONT size="2"&gt;&lt;SPAN class="sub_section_element_selectors"&gt; Occurs on non-Intel GPUs?: no tested&lt;/SPAN&gt;&lt;/FONT&gt;&lt;/P&gt;
&lt;/DIV&gt;
&lt;/DIV&gt;</description>
    <pubDate>Thu, 08 Sep 2022 19:49:18 GMT</pubDate>
    <dc:creator>Scott_S_2</dc:creator>
    <dc:date>2022-09-08T19:49:18Z</dc:date>
    <item>
      <title>OpenCL Graphics Driver 30.0.101.1069 Issue</title>
      <link>https://community.intel.com/t5/Graphics/OpenCL-Graphics-Driver-30-0-101-1069-Issue/m-p/1413601#M109657</link>
      <description>&lt;DIV class="lia-quilt-column lia-quilt-column-24 lia-quilt-column-single lia-quilt-column-message-body-content"&gt;
&lt;DIV class="lia-quilt-column-alley lia-quilt-column-alley-single"&gt;
&lt;P class="sub_section_element_selectors" style="word-wrap: break-word; font-size: 12px;"&gt;&lt;FONT size="2"&gt;&lt;SPAN class="sub_section_element_selectors"&gt;Hi all,&lt;/SPAN&gt;&lt;/FONT&gt;&lt;/P&gt;
&lt;P class="sub_section_element_selectors" style="word-wrap: break-word; font-size: 12px;"&gt;&lt;FONT size="2"&gt;I have just upgraded to the latest Intel Graphics Driver and I can no longer build opencl programs from spirv.&amp;nbsp; It seems image3d write is broken/missing as I get the following error for a simple opencl kernel:&lt;/FONT&gt;&lt;/P&gt;
&lt;PRE&gt;&lt;FONT size="2"&gt;failed to build opencl program:&lt;/FONT&gt;&lt;BR /&gt;&lt;BR /&gt;&lt;FONT size="2"&gt;error: undefined reference to `__builtin_spirv_OpImageWrite_img3d_wo_v3i32_v4f32'&lt;/FONT&gt;&lt;BR /&gt;&lt;FONT size="2"&gt;in function: '__builtin_spirv_OpImageWrite_img3d_wo_v3i32_v4f32' called by kernel: 'driver_test2'&lt;/FONT&gt;&lt;BR /&gt;&lt;BR /&gt;&lt;FONT size="2"&gt;error: backend compiler failed build.&lt;/FONT&gt;&lt;/PRE&gt;
&lt;P class="sub_section_element_selectors" style="word-wrap: break-word; font-size: 12px;"&gt;&lt;FONT size="2"&gt;&amp;nbsp;here is a simple kernel that triggers this:&lt;/FONT&gt;&lt;/P&gt;
&lt;LI-CODE lang="markup"&gt;#include &amp;lt;opencl_memory&amp;gt;
#include &amp;lt;opencl_work_item&amp;gt;
#include &amp;lt;opencl_image&amp;gt;
#include &amp;lt;opencl_integer&amp;gt;

using namespace cl;

kernel void driver_test(
    image3d&amp;lt;float4, image_access::write&amp;gt; dst_vol
) {
    const int3 dst_coords(get_global_id(0), get_global_id(1), get_global_id(2));

    float4 source_sample(0.0f,0.0f,0.0f,0.0f);
    dst_vol.write(dst_coords, source_sample);  
}&lt;/LI-CODE&gt;
&lt;P class="sub_section_element_selectors" style="word-wrap: break-word; font-size: 12px;"&gt;&lt;FONT size="2"&gt;&lt;SPAN class="sub_section_element_selectors"&gt;and the cpp part:&lt;/SPAN&gt;&lt;/FONT&gt;&lt;/P&gt;
&lt;LI-CODE lang="markup"&gt;#include "CL/cl.h"
#include &amp;lt;iostream&amp;gt;
#include &amp;lt;fstream&amp;gt;

#define MAX_PLATFORM_SIZE 256
#define MAX_DEVICE_SIZE 256

std::vector&amp;lt;unsigned char&amp;gt; load_file(const std::string&amp;amp; file)
{
    std::fstream input(file, std::ios::in | std::ios::binary | std::ios::ate);
    auto size = input.tellg();
    input.seekg(0, std::ios::beg);
    std::vector&amp;lt;unsigned char&amp;gt; binary(size);
    input.read((char*)binary.data(),size);
    input.close();

    return binary;
}

void driver_test()
{  
    std::vector&amp;lt;unsigned char&amp;gt; data = load_file("driver_test.spir");

    cl_device_id device_id[256];
    cl_platform_id platform_id[256];
    cl_uint ret_num_devices;
    cl_uint ret_num_platforms;
    char buf[4096];

    cl_int ret = clGetPlatformIDs(0, 0, &amp;amp;ret_num_platforms);
    ret = clGetPlatformIDs(ret_num_platforms, platform_id, &amp;amp;ret_num_platforms);
    if (ret != CL_SUCCESS) {
        std::cout &amp;lt;&amp;lt; "something went wrong in clGetPlatformIDs" &amp;lt;&amp;lt; std::endl;
        return;
    }

    for (unsigned int i=0; i&amp;lt;ret_num_platforms; i++) 
    {
        ret = clGetPlatformInfo(platform_id[i], CL_PLATFORM_NAME, sizeof(buf), buf, NULL);
        if (ret != CL_SUCCESS) {
            std::cout &amp;lt;&amp;lt; "something went wrong in clGetPlatformInfo" &amp;lt;&amp;lt; std::endl;
            return;
        }
        std::cout &amp;lt;&amp;lt; "Platform[" &amp;lt;&amp;lt; i &amp;lt;&amp;lt; "]: " &amp;lt;&amp;lt; buf &amp;lt;&amp;lt; std::endl;

        ret = clGetDeviceIDs(platform_id[i], CL_DEVICE_TYPE_ALL, MAX_DEVICE_SIZE, device_id, &amp;amp;ret_num_devices);
        if (ret != CL_SUCCESS) {
            std::cout &amp;lt;&amp;lt; "something went wrong in clGetDeviceIDs" &amp;lt;&amp;lt; std::endl;
            return;
        }

        for (unsigned int j=0; j&amp;lt;ret_num_devices; j++) {
            ret = clGetDeviceInfo(device_id[j], CL_DEVICE_NAME, sizeof(buf), buf, NULL);
            if (ret != CL_SUCCESS) {
                std::cout &amp;lt;&amp;lt; "something went wrong in clGetDeviceInfo" &amp;lt;&amp;lt; std::endl;
                return;
            }
            std::cout &amp;lt;&amp;lt; "Device Name: " &amp;lt;&amp;lt; buf &amp;lt;&amp;lt; std::endl;

            ret = clGetDeviceInfo(device_id[j], CL_DEVICE_VENDOR, sizeof(buf), buf, NULL);
            if (ret != CL_SUCCESS) {
                std::cout &amp;lt;&amp;lt; "something went wrong in clGetDeviceInfo" &amp;lt;&amp;lt; std::endl;
                return;
            }
            std::cout &amp;lt;&amp;lt; "Device Vendor: " &amp;lt;&amp;lt; buf &amp;lt;&amp;lt; std::endl;
        }
        std::cout &amp;lt;&amp;lt; std::endl;
    }
 
    cl_context context = clCreateContext( NULL, 1, &amp;amp;device_id[0], NULL, NULL, &amp;amp;ret);
 
    cl_int err = 0;
    cl_program program = clCreateProgramWithIL((cl_context)context, data.data(), data.size(), &amp;amp;err); 
    if(err != CL_SUCCESS){
        std::cout &amp;lt;&amp;lt; "failed to create opencl program with IL " &amp;lt;&amp;lt; std::endl;
        return;
    }

    // sometimes crashes here
    err = clBuildProgram(program, 1, &amp;amp;device_id[0], NULL, NULL, NULL);

    cl_int build_status;
    err = clGetProgramBuildInfo(program, device_id[0], CL_PROGRAM_BUILD_STATUS, sizeof(cl_build_status), &amp;amp;build_status, NULL);

    if(build_status != CL_SUCCESS){
        size_t ret_val_size;
        err = clGetProgramBuildInfo(program, device_id[0], CL_PROGRAM_BUILD_LOG, 0, NULL, &amp;amp;ret_val_size);
                 
        std::vector&amp;lt;char&amp;gt; build_log(ret_val_size+1,0);
        err = clGetProgramBuildInfo(program, device_id[0], CL_PROGRAM_BUILD_LOG, ret_val_size, build_log.data(), NULL);

        build_log[ret_val_size] = '\0';
        std::cout &amp;lt;&amp;lt; "failed to build opencl program: \n" &amp;lt;&amp;lt; build_log.data() &amp;lt;&amp;lt; std::endl;
    }
}
&lt;/LI-CODE&gt;
&lt;P class="sub_section_element_selectors" style="word-wrap: break-word; font-size: 12px;"&gt;&lt;FONT size="2"&gt;I've been rolling back the driver versions and the earliest driver where this happens is: &lt;STRONG&gt;30.0.101.1069&lt;/STRONG&gt;&lt;/FONT&gt;&lt;/P&gt;
&lt;P class="sub_section_element_selectors" style="word-wrap: break-word; font-size: 12px;"&gt;&lt;FONT size="2"&gt;Earlier driver version work fine&lt;/FONT&gt;&lt;/P&gt;
&lt;P class="sub_section_element_selectors" style="word-wrap: break-word; font-size: 12px;"&gt;&lt;FONT size="2"&gt;Sometimes it crashes at clBuildProgram too. &lt;/FONT&gt;&lt;/P&gt;
&lt;P class="sub_section_element_selectors" style="word-wrap: break-word; font-size: 12px;"&gt;&lt;FONT size="2"&gt;I have attached the .cl, cpp and .spir files.&amp;nbsp; We use:&lt;BR /&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp; &lt;A href="https://github.com/KhronosGroup/SPIRV-LLVM" target="_self"&gt;SPIRV-LLVM&lt;/A&gt;&lt;BR /&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp; &lt;A href="https://github.com/KhronosGroup/SPIR" target="_self"&gt;SPIR &lt;/A&gt;&lt;BR /&gt;&lt;/FONT&gt;&lt;FONT size="2"&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp; &lt;A href="https://github.com/KhronosGroup/libclcxx" target="_self"&gt;libclcxx&lt;/A&gt;&lt;/FONT&gt;&lt;/P&gt;
&lt;P class="sub_section_element_selectors" style="word-wrap: break-word; font-size: 12px;"&gt;&lt;FONT size="2"&gt;to generate the spirv file.&amp;nbsp; I've attached the generated spirv for easier testing.&lt;/FONT&gt;&lt;/P&gt;
&lt;P class="sub_section_element_selectors" style="word-wrap: break-word; font-size: 12px;"&gt;&lt;FONT size="2"&gt;Any help would be appreciated.&lt;/FONT&gt;&lt;/P&gt;
&lt;P class="sub_section_element_selectors" style="word-wrap: break-word; font-size: 12px;"&gt;&lt;FONT size="2"&gt;Regards&lt;/FONT&gt;&lt;BR /&gt;&lt;FONT size="2"&gt;Scott&lt;/FONT&gt;&lt;/P&gt;
&lt;P class="sub_section_element_selectors" style="word-wrap: break-word; font-size: 12px;"&gt;&amp;nbsp;&lt;/P&gt;
&lt;P class="sub_section_element_selectors" style="word-wrap: break-word; font-size: 12px;"&gt;&lt;FONT size="2"&gt;&lt;SPAN class="sub_section_element_selectors"&gt;System Setup Information:&lt;/SPAN&gt;&lt;/FONT&gt;&lt;BR /&gt;&lt;FONT size="2"&gt;&lt;SPAN class="sub_section_element_selectors"&gt; -----------------------------------------&lt;/SPAN&gt;&lt;/FONT&gt;&lt;/P&gt;
&lt;P class="sub_section_element_selectors" style="word-wrap: break-word; font-size: 12px;"&gt;&lt;FONT size="2"&gt;&lt;SPAN class="sub_section_element_selectors"&gt;System Used: Inspiron 3670&lt;/SPAN&gt;&lt;/FONT&gt;&lt;BR /&gt;&lt;FONT size="2"&gt;&lt;SPAN class="sub_section_element_selectors"&gt; CPU SKU: Intel(R) Core(TM) i3-8100 CPU @ 3.60GHz 3.60 GHz&lt;/SPAN&gt;&lt;/FONT&gt;&lt;BR /&gt;&lt;FONT size="2"&gt;&lt;SPAN class="sub_section_element_selectors"&gt; GPU SKU: Intel(R) UHD Graphics 630&lt;/SPAN&gt;&lt;/FONT&gt;&lt;BR /&gt;&lt;FONT size="2"&gt;&lt;SPAN class="sub_section_element_selectors"&gt; System BIOS Version: Dell Inc. 1.3.4, 24/05/2018&lt;/SPAN&gt;&lt;/FONT&gt;&lt;BR /&gt;&lt;FONT size="2"&gt;&lt;SPAN class="sub_section_element_selectors"&gt; Graphics Driver Version: 30.0.101.1069&lt;/SPAN&gt;&lt;/FONT&gt;&lt;BR /&gt;&lt;FONT size="2"&gt;&lt;SPAN class="sub_section_element_selectors"&gt; Operating System:&amp;nbsp; Windows 10 Pro&lt;/SPAN&gt;&lt;/FONT&gt;&lt;BR /&gt;&lt;FONT size="2"&gt;&lt;SPAN class="sub_section_element_selectors"&gt; OS Version: 10.0.19042 Build 19042&lt;/SPAN&gt;&lt;/FONT&gt;&lt;BR /&gt;&lt;FONT size="2"&gt;&lt;SPAN class="sub_section_element_selectors"&gt; API: OpenCL&lt;/SPAN&gt;&lt;/FONT&gt;&lt;BR /&gt;&lt;FONT size="2"&gt;&lt;SPAN class="sub_section_element_selectors"&gt; Occurs on non-Intel GPUs?: no tested&lt;/SPAN&gt;&lt;/FONT&gt;&lt;/P&gt;
&lt;/DIV&gt;
&lt;/DIV&gt;</description>
      <pubDate>Thu, 08 Sep 2022 19:49:18 GMT</pubDate>
      <guid>https://community.intel.com/t5/Graphics/OpenCL-Graphics-Driver-30-0-101-1069-Issue/m-p/1413601#M109657</guid>
      <dc:creator>Scott_S_2</dc:creator>
      <dc:date>2022-09-08T19:49:18Z</dc:date>
    </item>
  </channel>
</rss>

